@@ -37,7 +37,7 @@
    stands in the Real World!  :-D  */
 #include <stdint.h>
 #include <stdbool.h>
-#include <SDL/SDL.h>
+#include "SDL.h"
 
 
 #define GCC_VERSION  (__GNUC__ * 10000           \
@@ -49,6 +49,12 @@
 #define DSOPRIVATE
 #endif
 
+#if GCC_VERSION >= 20700
+#define UNUSED  __attribute__ ((__unused__))
+#else
+#define UNUSED
+#endif
+
 #define GBO  DSOPRIVATE extern
 
 
@@ -194,8 +200,8 @@ typedef struct {
   const long const *val;
   SCM *linear;
   SCM table;
-  int classic:1;                        /* boolean */
-  int offset:1;                         /* boolean */
+  bool classic;
+  bool offset;
   struct symset ss;
 } kp_t;
 
@@ -304,7 +310,7 @@ typedef void (register_kf_v_t) (size_t count, kf_init_t v[count]);
 
 struct obtw
 {
-  long smob_tags[4];
+  smob_tag_t smob_tags[4];
   /* These are: color, rect, surface, pixel format.  */
 
   SCM video_flags;
