@@ -28,7 +28,7 @@ static SCM cdrom_state;
 static SCM cd_track_type;
 #include "k/cdtracktype.c"
 
-static long cdrom_tag;
+static smob_tag_t cdrom_tag;
 
 #define cdrom_nick "SDL-CD"
 
@@ -480,7 +480,7 @@ free_cd (SCM cdrom)
 
 static
 int
-print_cd (SCM cdrom, SCM port, scm_print_state *pstate)
+print_cd (SCM cdrom, SCM port, UNUSED scm_print_state *pstate)
 {
   SDL_CD *cd = UNPACK_CDROM (cdrom);
   char buf[32], *status;
