@@ -109,7 +109,7 @@ sorry (const char *FUNC_NAME, const char *nick, SCM symbol)
 
 #define enum_nick "SDL-enum"
 
-static long enum_tag;
+static smob_tag_t enum_tag;
 
 #define ASSERT_ENUM(obj,which) \
   ASSERT_SMOB (obj, enum, which)
@@ -129,7 +129,7 @@ mark_enum (SCM enumstash)
 
 static
 int
-print_enum (SCM smob, SCM port, scm_print_state *ps)
+print_enum (SCM smob, SCM port, UNUSED scm_print_state *ps)
 {
   kp_t *stash = UNPACK_ENUM (smob);
   const struct symset *ss = &stash->ss;
@@ -157,10 +157,14 @@ register_kp (kp_t *kp)
   ht = GC_PROTECT (MAKE_HASH_TABLE (count));
   for (i = 0; i < count; i++)
     {
+      /* A ridiculous variable solely to avoid a GCC "warning: signed
+         and unsigned type in conditional expression [-Wsign-compare]".
+         Maybe there's a better way?  */
+      long ival = i;
       long value = (kp->classic
-                    ? i
+                    ? ival
                     : (kp->offset
-                       ? i + kp->val[0]
+                       ? ival + kp->val[0]
                        : kp->val[i]));
       uint8_t len = *pool++;
       SCM sym = GC_PROTECT (SYMBOLN ((char *) pool, len));
@@ -206,7 +210,7 @@ enum2long (const sym2num_cc_t *cc, SCM obj)
   const char *FUNC_NAME = cc->who;
   long result = 0;
   kp_t *e = UNPACK_ENUM (cc->stash);
-  size_t idx;
+  long idx;
 
   if (SCM_SYMBOLP (obj))
     {
@@ -305,7 +309,7 @@ if it does not belong to @var{stash}.  */)
 
 #define flagstash_nick "SDL-flagstash"
 
-static unsigned long int flagstash_tag;
+static smob_tag_t flagstash_tag;
 
 #define ASSERT_FLAGSTASH(obj,which) \
   ASSERT_SMOB (obj, flagstash, which)
@@ -324,7 +328,7 @@ mark_flagstash (SCM smob)
 
 static
 int
-print_flagstash (SCM smob, SCM port, scm_print_state *ps)
+print_flagstash (SCM smob, SCM port, UNUSED scm_print_state *ps)
 {
   flagstash_t *stash = UNPACK_FLAGSTASH (smob);
   const struct symset *ss = &stash->ss;
@@ -429,7 +433,7 @@ ulong2flags (unsigned long value, SCM stash)
 {
   flagstash_t *s = UNPACK_FLAGSTASH (stash);
   size_t count = s->ss.count;
-  int i;
+  size_t i;
   SCM rv = SCM_EOL;
 
   /* Is nothing really nothing?  A stash is in descending order, so
@@ -564,7 +568,7 @@ and @var{type} is a symbol: @code{enums} or @code{flags}.  */)
 #define FUNC_NAME s_kotk
   kp_t *kp;
   flagstash_t *kf;
-  int i;
+  size_t i;
   SCM k, symbol, rv = SCM_EOL;
 
 #define ACC(KEXP,VEXP)  do                      \
