@@ -823,7 +823,7 @@ box RGBA or Y information'' and is in 32-bit RGBA format.  */)
 
 #include "SDL_gfx/SDL_framerate.h"
 
-static long fpsmgr_tag;
+static smob_tag_t fpsmgr_tag;
 
 #define fpsmgr_nick "SDL-FPS-Manager"
 
@@ -842,7 +842,7 @@ free_fpsmgr (SCM fpsmgr)
 
 static
 int
-print_fpsmgr (SCM fpsmgr, SCM port, scm_print_state *pstate)
+print_fpsmgr (SCM fpsmgr, SCM port, UNUSED scm_print_state *pstate)
 {
   FPSmanager *m = UNPACK_FPSMGR (fpsmgr);
   char buf[24];
