@@ -21,7 +21,7 @@
 
 #define GUILE_SDL_OPTIONAL_MODULE  1
 #include "guile-sdl.h"
-#include <SDL/SDL_mixer.h>
+#include "SDL_mixer.h"
 #include "snuggle/finangle.h"
 #include "b-values.h"
 
@@ -35,8 +35,8 @@ static SCM fading_status_enum;
 #define RETURN_FADINGSTATUS(x)  return btw->long2enum ((x), fading_status_enum)
 
 
-static long mix_music_tag;
-static long mix_audio_tag;
+static smob_tag_t mix_music_tag;
+static smob_tag_t mix_audio_tag;
 
 #define mix_music_nick "SDL-Music"
 #define mix_audio_nick "SDL-Audio"
@@ -91,7 +91,7 @@ those aspects of the device.  Return @code{#t} if successful.  */)
 
   /* Open the audio device.  */
   RETURN_TRUE_IF_0
-    (Mix_OpenAudio (cfreq, MIX_DEFAULT_FORMAT, cchannels, 1024));
+    (Mix_OpenAudio (cfreq, cformat, cchannels, cchunksize));
 #undef FUNC_NAME
 }
 
