@@ -21,7 +21,7 @@
 
 #include "guile-sdl.h"
 #include <stdio.h>
-#include <SDL/SDL_image.h>
+#include "SDL_image.h"
 #include "snuggle/finangle.h"
 #include "b-uv.h"
 #include "b-values.h"
@@ -73,8 +73,8 @@ DECLARE_PF (Cursor);
 
 
 /* tags for SDL smobs */
-static long cursor_tag;
-static long overlay_tag;
+static smob_tag_t cursor_tag;
+static smob_tag_t overlay_tag;
 #define overlay_nick "SDL-Overlay"
 
 #define ASSERT_CURSOR(obj,which)   ASSERT_SMOB (obj, cursor, which)
@@ -117,7 +117,7 @@ free_yuv_overlay (SCM overlay)
 
 static
 size_t
-free_pixel_format (SCM pixel_format)
+free_pixel_format (UNUSED SCM pixel_format)
 {
   /* Always part of a surface.  */
   return 0;
@@ -125,7 +125,7 @@ free_pixel_format (SCM pixel_format)
 
 static
 int
-print_pixel_format (SCM pixel_format, SCM port, scm_print_state *pstate)
+print_pixel_format (SCM pixel_format, SCM port, UNUSED scm_print_state *pstate)
 {
   SDL_PixelFormat *f = UNPACK_PIXEL_FORMAT (pixel_format);
   char buf[80];
